@@ -9,11 +9,11 @@ impl AWSMachineTemplate {
     }
 
     pub fn t3small(name: &str) -> Self {
-        Self::with_type(name, "t3small")
+        Self::with_type(name, "t3.small")
     }
 
     pub fn m5xlarge(name: &str) -> Self {
-        Self::with_type(name, "m5xlarge")
+        Self::with_type(name, "m5.xlarge")
     }
 
     pub fn ssh_key_name(mut self, name: &str) -> Self {
